package com.sun.org.apache.xml.internal.security.c14n.implementations;

import org.w3c.dom.Node;
import java.util.Iterator;
import org.w3c.dom.Attr;
import java.util.Collection;
import java.util.ArrayList;
import java.util.List;

public class NameSpaceSymbTable
{
    private static final String XMLNS = "xmlns";
    private static final SymbMap initialMap;
    private SymbMap symb;
    private List<SymbMap> level;
    private boolean cloned;
    
    public NameSpaceSymbTable() {
        this.cloned = true;
        this.level = new ArrayList();
        this.symb = (SymbMap)NameSpaceSymbTable.initialMap.clone();
    }
    
    public void getUnrenderedNodes(Collection<Attr> collection) {
        for (NameSpaceSymbEntry nameSpaceSymbEntry : this.symb.entrySet()) {
            if (!nameSpaceSymbEntry.rendered && nameSpaceSymbEntry.n != null) {
                NameSpaceSymbEntry nameSpaceSymbEntry2 = (NameSpaceSymbEntry)nameSpaceSymbEntry.clone();
                this.needsClone();
                this.symb.put(nameSpaceSymbEntry2.prefix, nameSpaceSymbEntry2);
                nameSpaceSymbEntry2.lastrendered = nameSpaceSymbEntry2.uri;
                nameSpaceSymbEntry2.rendered = true;
                collection.add(nameSpaceSymbEntry2.n);
            }
            else {
                continue;
            }
        }
    }
    
    public void outputNodePush() {
        this.push();
    }
    
    public void outputNodePop() {
        this.pop();
    }
    
    public void push() {
        this.level.add(null);
        this.cloned = false;
    }
    
    public void pop() {
        int n = this.level.size() - 1;
        Object remove = this.level.remove(n);
        if (remove != null) {
            this.symb = (SymbMap)remove;
            if (n == 0) {
                this.cloned = false;
            }
            else {
                this.cloned = (this.level.get(n - 1) != this.symb);
            }
        }
        else {
            this.cloned = false;
        }
    }
    
    final void needsClone() {
        if (!this.cloned) {
            this.level.set(this.level.size() - 1, this.symb);
            this.symb = (SymbMap)this.symb.clone();
            this.cloned = true;
        }
    }
    
    public Attr getMapping(String s) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value == null) {
            return null;
        }
        if (value.rendered) {
            return null;
        }
        NameSpaceSymbEntry nameSpaceSymbEntry = (NameSpaceSymbEntry)value.clone();
        this.needsClone();
        this.symb.put(s, nameSpaceSymbEntry);
        nameSpaceSymbEntry.rendered = true;
        nameSpaceSymbEntry.lastrendered = nameSpaceSymbEntry.uri;
        return nameSpaceSymbEntry.n;
    }
    
    public Attr getMappingWithoutRendered(String s) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value == null) {
            return null;
        }
        if (value.rendered) {
            return null;
        }
        return value.n;
    }
    
    public boolean addMapping(String s, String anObject, Attr attr) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value != null && anObject.equals(value.uri)) {
            return false;
        }
        NameSpaceSymbEntry nameSpaceSymbEntry = new NameSpaceSymbEntry(anObject, attr, false, s);
        this.needsClone();
        this.symb.put(s, nameSpaceSymbEntry);
        if (value != null) {
            nameSpaceSymbEntry.lastrendered = value.lastrendered;
            if (value.lastrendered != null && value.lastrendered.equals(anObject)) {
                nameSpaceSymbEntry.rendered = true;
            }
        }
        return true;
    }
    
    public Node addMappingAndRender(String s, String lastrendered, Attr attr) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value != null && lastrendered.equals(value.uri)) {
            if (!value.rendered) {
                NameSpaceSymbEntry nameSpaceSymbEntry2 = (NameSpaceSymbEntry)value.clone();
                this.needsClone();
                this.symb.put(s, nameSpaceSymbEntry2);
                nameSpaceSymbEntry2.lastrendered = lastrendered;
                nameSpaceSymbEntry2.rendered = true;
                return nameSpaceSymbEntry2.n;
            }
            return null;
        }
        else {
            NameSpaceSymbEntry nameSpaceSymbEntry = new NameSpaceSymbEntry(lastrendered, attr, true, s);
            nameSpaceSymbEntry.lastrendered = lastrendered;
            this.needsClone();
            this.symb.put(s, nameSpaceSymbEntry);
            if (value != null && value.lastrendered != null && value.lastrendered.equals(lastrendered)) {
                nameSpaceSymbEntry.rendered = true;
                return null;
            }
            return nameSpaceSymbEntry.n;
        }
    }
    
    public int getLevel() {
        return this.level.size();
    }
    
    public void removeMapping(String s) {
        if (this.symb.get(s) != null) {
            this.needsClone();
            this.symb.put(s, null);
        }
    }
    
    public void removeMappingIfNotRender(String s) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value != null && !value.rendered) {
            this.needsClone();
            this.symb.put(s, null);
        }
    }
    
    public boolean removeMappingIfRender(String s) {
        NameSpaceSymbEntry value = this.symb.get(s);
        if (value != null && value.rendered) {
            this.needsClone();
            this.symb.put(s, null);
        }
        return false;
    }
    
    static {
        initialMap = new SymbMap();
        NameSpaceSymbEntry nameSpaceSymbEntry = new NameSpaceSymbEntry("", null, true, "xmlns");
        nameSpaceSymbEntry.lastrendered = "";
        NameSpaceSymbTable.initialMap.put("xmlns", nameSpaceSymbEntry);
    }
}
